/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.server.schema.bootstrap;


import java.util.ArrayList;
import javax.naming.NamingException;
import org.apache.directory.shared.ldap.schema.ObjectClassTypeEnum;
import org.apache.directory.server.schema.registries.*;


/**
 * A producer of schema objectClass definations for the samba schema.  This
 * code has been automatically generated using schema files in the OpenLDAP
 * format along with the directory plugin for maven.  This has been done
 * to facilitate OpenLDAP schema interoperability.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev$
 */
public class SambaObjectClassProducer extends AbstractBootstrapProducer
{

    public SambaObjectClassProducer()
    {
        super( ProducerTypeEnum.OBJECT_CLASS_PRODUCER );
    }


    // ------------------------------------------------------------------------
    // BootstrapProducer Methods
    // ------------------------------------------------------------------------


    /**
     * @see BootstrapProducer#produce(Registries, ProducerCallback)
     */
    public void produce( Registries registries, ProducerCallback cb )
        throws NamingException
    {
        ArrayList<String> array = new ArrayList<String>();
        BootstrapObjectClass objectClass;

        
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.6 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.6", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba 3.0 Auxilary SAM Account" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "uid" );
        array.add( "sambaSID" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "cn" );
        array.add( "sambaLMPassword" );
        array.add( "sambaNTPassword" );
        array.add( "sambaPwdLastSet" );
        array.add( "sambaLogonTime" );
        array.add( "sambaLogoffTime" );
        array.add( "sambaKickoffTime" );
        array.add( "sambaPwdCanChange" );
        array.add( "sambaPwdMustChange" );
        array.add( "sambaAcctFlags" );
        array.add( "displayName" );
        array.add( "sambaHomePath" );
        array.add( "sambaHomeDrive" );
        array.add( "sambaLogonScript" );
        array.add( "sambaProfilePath" );
        array.add( "description" );
        array.add( "sambaUserWorkstations" );
        array.add( "sambaPrimaryGroupSID" );
        array.add( "sambaDomainName" );
        array.add( "sambaMungedDial" );
        array.add( "sambaBadPasswordCount" );
        array.add( "sambaBadPasswordTime" );
        array.add( "sambaPasswordHistory" );
        array.add( "sambaLogonHours" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaSamAccount" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.6", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.4 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.4", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Group Mapping" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "gidNumber" );
        array.add( "sambaSID" );
        array.add( "sambaGroupType" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "displayName" );
        array.add( "description" );
        array.add( "sambaSIDList" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaGroupMapping" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.4", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.14 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.14", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Trust Password" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaDomainName" );
        array.add( "sambaNTPassword" );
        array.add( "sambaTrustFlags" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "sambaSID" );
        array.add( "sambaPwdLastSet" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaTrustPassword" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.14", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.5 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.5", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Domain Information" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaDomainName" );
        array.add( "sambaSID" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "sambaNextRid" );
        array.add( "sambaNextGroupRid" );
        array.add( "sambaNextUserRid" );
        array.add( "sambaAlgorithmicRidBase" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaDomain" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.5", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.7 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.7", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Pool for allocating UNIX uids/gids" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "uidNumber" );
        array.add( "gidNumber" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaUnixIdPool" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.7", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.8 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.8", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Mapping from a SID to an ID" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaSID" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "uidNumber" );
        array.add( "gidNumber" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaIdmapEntry" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.8", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.9 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.9", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Structural Class for a SID" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaSID" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaSidEntry" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.9", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.1.2.2.10 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.1.2.2.10", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Configuration Section" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaConfig" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.1.2.2.10", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.11 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.11", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Share Section" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaShareName" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaShare" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.11", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.12 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.12", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Configuration Option" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaOptionName" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "sambaBoolOption" );
        array.add( "sambaIntegerOption" );
        array.add( "sambaStringOption" );
        array.add( "sambaStringListoption" );
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaConfigOption" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.12", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.4.1.7165.2.2.13 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.4.1.7165.2.2.13", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Samba Privilege" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "sambaSID" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "sambaPrivilegeList" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "sambaPrivilege" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.4.1.7165.2.2.13", objectClass );

    }
}
